@@ -230,12 +230,7 @@ void mcurses_final()
 {
     int i;
 
-    for(i=0; i<vector_size(gKeyMap); i++) {
-        FREE(vector_item(gKeyMap, i));
-    }
-    vector_delete(gKeyMap);
     close(gMCTtyFd);
-    FREE(gBuffer);
     
     //mreset_tty();
 }
