@@ -33,7 +33,7 @@ typedef struct {
 ///////////////////////////////////////////////////////////////////////
 
 // 
-#ifdef MDEBUG
+#if defined(MDEBUG)
 
 hash_obj* hash_new_debug(int size, const char* fname, int line, const char* func_name);
 #define HASH_NEW(size) hash_new_debug(size, __FILE__, __LINE__, __FUNCTION__)
