@@ -743,7 +743,7 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
             /// 実行 ///
             *rcode = run(fun->statments, title
                 , nextout, nextin, nexterr, return_, blocks, FALSE);
-            *return_ = FALSE;
+            *return_ = FALSE; // ユーザー関数が復帰したらreturn終わり
 
             if(strcmp(string_c_str(fun->arg_name), "") == 0) {
                 /// スタックを消す ///
@@ -881,7 +881,6 @@ static BOOL statment_tree(sStatment* statment, int* last_program_pid, sWFd* pipe
         /// 外部コマンド ///
         else {
 //puts("外部コマンド");
-
             /// バッファーをフラッシュしておく
             if(nextout == pipeout) {
                 if(!sWFd_flash(nextout)) {
